@@ -1,7 +1,7 @@
 /* dn2id.c - routines to deal with the dn2id index */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/dn2id.c,v 1.50.2.7 2002/12/14 21:11:51 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/dn2id.c,v 1.50.2.8 2003/02/09 16:31:37 kurt Exp $ */
 /*
- * Copyright 1998-2002 The OpenLDAP Foundation, All Rights Reserved.
+ * Copyright 1998-2003 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
  */
 
@@ -67,22 +67,27 @@ bdb_dn2id_add(
 		goto done;
 	}
 
+#ifndef BDB_MULTIPLE_SUFFIXES
 	if( !be_issuffix( be, &ptr )) {
+#endif
 		buf[0] = DN_SUBTREE_PREFIX;
-		rc = bdb_idl_insert_key( be, db, txn, &key, e->e_id );
+		rc = db->put( db, txn, &key, &data, DB_NOOVERWRITE );
 		if( rc != 0 ) {
 #ifdef NEW_LOGGING
 			LDAP_LOG ( INDEX, ERR, 
-				"=> bdb_dn2id_add: subtree (%s) insert failed: %d\n",
+				"=> bdb_dn2id_add: subtree (%s) put failed: %d\n",
 				ptr.bv_val, rc, 0 );
 #else
 			Debug( LDAP_DEBUG_ANY,
-			"=> bdb_dn2id_add: subtree (%s) insert failed: %d\n",
+			"=> bdb_dn2id_add: subtree (%s) put failed: %d\n",
 			ptr.bv_val, rc, 0 );
 #endif
 			goto done;
 		}
 		
+#ifdef BDB_MULTIPLE_SUFFIXES
+	if( !be_issuffix( be, &ptr )) {
+#endif
 		dnParent( &ptr, &pdn );
 	
 		key.size = pdn.bv_len + 2;
@@ -105,9 +110,13 @@ bdb_dn2id_add(
 #endif
 			goto done;
 		}
+#ifndef BDB_MULTIPLE_SUFFIXES
 	}
 
 	while( !be_issuffix( be, &ptr )) {
+#else
+	for (;;) {
+#endif
 		ptr.bv_val[-1] = DN_SUBTREE_PREFIX;
 
 		rc = bdb_idl_insert_key( be, db, txn, &key, e->e_id );
@@ -124,6 +133,9 @@ bdb_dn2id_add(
 #endif
 			break;
 		}
+#ifdef BDB_MULTIPLE_SUFFIXES
+		if( be_issuffix( be, &ptr )) break;
+#endif
 		dnParent( &ptr, &pdn );
 
 		key.size = pdn.bv_len + 2;
@@ -131,6 +143,9 @@ bdb_dn2id_add(
 		key.data = pdn.bv_val - 1;
 		ptr = pdn;
 	}
+#ifdef BDB_MULTIPLE_SUFFIXES
+	}
+#endif
 
 done:
 	ch_free( buf );
@@ -189,7 +204,9 @@ bdb_dn2id_delete(
 		goto done;
 	}
 
+#ifndef BDB_MULTIPLE_SUFFIXES
 	if( !be_issuffix( be, &ptr )) {
+#endif
 		buf[0] = DN_SUBTREE_PREFIX;
 		rc = db->del( db, txn, &key, 0 );
 		if( rc != 0 ) {
@@ -205,6 +222,9 @@ bdb_dn2id_delete(
 			goto done;
 		}
 
+#ifdef BDB_MULTIPLE_SUFFIXES
+	if( !be_issuffix( be, &ptr )) {
+#endif
 		dnParent( &ptr, &pdn );
 
 		key.size = pdn.bv_len + 2;
@@ -227,9 +247,13 @@ bdb_dn2id_delete(
 #endif
 			goto done;
 		}
+#ifndef BDB_MULTIPLE_SUFFIXES
 	}
 
 	while( !be_issuffix( be, &ptr )) {
+#else
+	for (;;) {
+#endif
 		ptr.bv_val[-1] = DN_SUBTREE_PREFIX;
 
 		rc = bdb_idl_delete_key( be, db, txn, &key, e->e_id );
@@ -245,6 +269,9 @@ bdb_dn2id_delete(
 #endif
 			goto done;
 		}
+#ifdef BDB_MULTIPLE_SUFFIXES
+		if( be_issuffix( be, &ptr )) break;
+#endif
 		dnParent( &ptr, &pdn );
 
 		key.size = pdn.bv_len + 2;
@@ -252,6 +279,9 @@ bdb_dn2id_delete(
 		key.data = pdn.bv_val - 1;
 		ptr = pdn;
 	}
+#ifdef BDB_MULTIPLE_SUFFIXES
+	}
+#endif
 
 done:
 	ch_free( buf );
@@ -525,11 +555,13 @@ bdb_dn2idl(
 	Debug( LDAP_DEBUG_TRACE, "=> bdb_dn2idl( \"%s\" )\n", dn->bv_val, 0, 0 );
 #endif
 
+#ifndef	BDB_MULTIPLE_SUFFIXES
 	if (prefix == DN_SUBTREE_PREFIX && be_issuffix(be, dn))
 	{
 		BDB_IDL_ALL(bdb, ids);
 		return 0;
 	}
+#endif
 
 	DBTzero( &key );
 	key.size = dn->bv_len + 2;
@@ -622,28 +654,32 @@ node_find_cmp(
 
 static int
 node_frdn_cmp(
-	struct berval *nrdn,
-	idNode *n
+	const void *v_nrdn,
+	const void *v_n
 )
 {
+	const struct berval *nrdn = v_nrdn;
+	const idNode *n = v_n;
 	return ber_bvcmp(nrdn, &n->i_rdn->nrdn);
 }
 
 static int
 node_add_cmp(
-	idNode *a,
-	idNode *b
+	const void *v_a,
+	const void *v_b
 )
 {
+	const idNode *a = v_a, *b = v_b;
 	return a->i_id - b->i_id;
 }
 
 static int
 node_rdn_cmp(
-	idNode *a,
-	idNode *b
+	const void *v_a,
+	const void *v_b
 )
 {
+	const idNode *a = v_a, *b = v_b;
 	/* should be slightly better without ordering drawbacks */
 	return ber_bvcmp(&a->i_rdn->nrdn, &b->i_rdn->nrdn);
 }
@@ -661,15 +697,17 @@ idNode * bdb_find_rdn_node(
 	Avlnode *tree
 )
 {
-	return avl_find(tree, (const void *)nrdn, (AVL_CMP)node_frdn_cmp);
+	return avl_find(tree, nrdn, node_frdn_cmp);
 }
 
 /* This function links a node into its parent's i_kids tree. */
-int bdb_insert_kid(
-	idNode *a,
-	Avlnode *tree
+static int bdb_insert_kid(
+	void *v_a,
+	void *v_tree
 )
 {
+	idNode *a = v_a;
+	Avlnode *tree = v_tree;
 	int rc;
 
 	if (a->i_rdn->parent == 0)
@@ -679,7 +717,7 @@ int bdb_insert_kid(
 		return -1;
 	ldap_pvt_thread_rdwr_wlock(&a->i_parent->i_kids_rdwr);
 	rc = avl_insert( &a->i_parent->i_kids, (caddr_t) a,
-		(AVL_CMP)node_rdn_cmp, (AVL_DUP) avl_dup_error );
+	                 node_rdn_cmp, avl_dup_error );
 	ldap_pvt_thread_rdwr_wunlock(&a->i_parent->i_kids_rdwr);
 	return rc;
 }
@@ -701,8 +739,7 @@ idNode *bdb_add_node(
 	node->i_rdn->rdn.bv_val += (long)d;
 	node->i_rdn->nrdn.bv_val += (long)d;
 	ldap_pvt_thread_rdwr_init(&node->i_kids_rdwr);
-	avl_insert( &bdb->bi_tree, (caddr_t) node,
-			(AVL_CMP)node_add_cmp, (AVL_DUP) avl_dup_error );
+	avl_insert( &bdb->bi_tree, (caddr_t) node, node_add_cmp, avl_dup_error );
 	if (id == 1)
 		bdb->bi_troot = node;
 	return node;
@@ -741,7 +778,7 @@ int bdb_build_tree(
 	}
 	cursor->c_close( cursor );
 
-	rc = avl_apply(bdb->bi_tree, (AVL_APPLY)bdb_insert_kid, bdb->bi_tree,
+	rc = avl_apply(bdb->bi_tree, bdb_insert_kid, bdb->bi_tree,
 		-1, AVL_INORDER );
 
 	return rc;
@@ -880,8 +917,7 @@ bdb_dn2id_delete(
 	if (n) {
 		if (n->i_parent) {
 			ldap_pvt_thread_rdwr_wlock(&n->i_parent->i_kids_rdwr);
-			avl_delete(&n->i_parent->i_kids, &n->i_rdn->nrdn,
-				(AVL_CMP)node_frdn_cmp);
+			avl_delete(&n->i_parent->i_kids, &n->i_rdn->nrdn, node_frdn_cmp);
 			ldap_pvt_thread_rdwr_wunlock(&n->i_parent->i_kids_rdwr);
 		}
 		free(n->i_rdn);
@@ -908,6 +944,7 @@ bdb_dn2id_matched(
 	struct berval	rdn;
 	char		*p1, *p2;
 	idNode *n, *p;
+	int		rc = 0;
 
 	if (!bdb->bi_troot)
 		return DB_NOTFOUND;
@@ -940,8 +977,11 @@ bdb_dn2id_matched(
 		*id = n->i_id;
 	} else if (id2) {
 		*id2 = p->i_id;
+	} else {
+		rc = DB_NOTFOUND;
 	}
-	return n ? 0 : DB_NOTFOUND;
+
+	return rc;
 }
 
 int
@@ -986,26 +1026,29 @@ bdb_dn2id_children(
  */
 static int
 insert_one(
-	idNode *n,
-	ID *ids
+	void *v_n,
+	void *v_ids
 )
 {
+	idNode *n = v_n;
+	ID *ids = v_ids;
 	return bdb_idl_insert(ids, n->i_id);
 }
 
 static int
 insert_sub(
-	idNode *n,
-	ID *ids
+	void *v_n,
+	void *v_ids
 )
 {
+	idNode *n = v_n;
+	ID *ids = v_ids;
 	int rc;
 
 	rc = bdb_idl_insert(ids, n->i_id);
 	if (rc == 0) {
 		ldap_pvt_thread_rdwr_rlock(&n->i_kids_rdwr);
-		rc = avl_apply(n->i_kids, (AVL_APPLY)insert_sub, ids, -1,
-			AVL_INORDER);
+		rc = avl_apply(n->i_kids, insert_sub, ids, -1, AVL_INORDER);
 		ldap_pvt_thread_rdwr_runlock(&n->i_kids_rdwr);
 	}
 	return rc;
@@ -1038,11 +1081,12 @@ bdb_dn2idl(
 	ids[0] = 0;
 	ldap_pvt_thread_rdwr_rlock(&n->i_kids_rdwr);
 	if (prefix == DN_ONE_PREFIX) {
-		rc = avl_apply(n->i_kids, (AVL_APPLY)insert_one, ids, -1,
-			AVL_INORDER);
+		rc = avl_apply(n->i_kids, insert_one, ids, -1, AVL_INORDER);
 	} else {
-		rc = avl_apply(n->i_kids, (AVL_APPLY)insert_sub, ids, -1,
-			AVL_INORDER);
+		ids[0] = 1;
+		ids[1] = id;
+		if (n->i_kids)
+			rc = avl_apply(n->i_kids, insert_sub, ids, -1, AVL_INORDER);
 	}
 	ldap_pvt_thread_rdwr_runlock(&n->i_kids_rdwr);
 	return rc;
