@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/servers/slapd/sasl.c,v 1.81.2.24 2003/03/12 20:58:18 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/sasl.c,v 1.81.2.25 2003/03/24 03:54:12 kurt Exp $ */
 /*
  * Copyright 1998-2003 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -349,13 +349,16 @@ sasl_ap_lookup(
 		}
 		a = attr_find( e->e_attrs, ad );
 		if ( !a ) continue;
-		if ( ! access_allowed( be, conn, op, e, ad, NULL, ACL_AUTH, NULL ) )
+		if ( ! access_allowed( be, conn, op, e, ad, NULL, ACL_AUTH, NULL ) ) {
 			continue;
-		if ( sl->list[i].values && ( sl->flags & SASL_AUXPROP_OVERRIDE ) )
-			sl->sparams->utils->prop_erase( sl->sparams->propctx, sl->list[i].name );
+		}
+		if ( sl->list[i].values && ( sl->flags & SASL_AUXPROP_OVERRIDE ) ) {
+			sl->sparams->utils->prop_erase( sl->sparams->propctx,
+			sl->list[i].name );
+		}
 		for ( bv = a->a_vals; bv->bv_val; bv++ ) {
-			sl->sparams->utils->prop_set( sl->sparams->propctx, sl->list[i].name,
-				bv->bv_val, bv->bv_len );
+			sl->sparams->utils->prop_set( sl->sparams->propctx,
+				sl->list[i].name, bv->bv_val, bv->bv_len );
 		}
 	}
 	return LDAP_SUCCESS;
